pub unsafe trait MaybeOwned: 'static { }Expand description
A trait for determining whether the buffer is owned or borrowed.
When the completion-based feature is enabled, this trait requires a 'static
lifetime bound to ensure buffers can be safely used in completion-based I/O.
Safety
Do not implement this trait manually. It is automatically implemented for all
types with a 'static lifetime.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl<T: 'static> MaybeOwned for T
Available on crate feature
completion-based only.