MaybeSend

Trait MaybeSend 

pub unsafe trait MaybeSend { }
A trait representing types that may or may not require Send.

When the no-send feature is enabled, this trait has no Send bound, allowing use with single-threaded async runtimes.

Safety

Do not implement this trait directly. It is automatically implemented for all types.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> MaybeSend for T

Available on crate feature no-send only.