MaybeSendFuture

Trait MaybeSendFuture 

pub trait MaybeSendFuture: Future + MaybeSend { }
A trait representing futures that may or may not require Send.

This trait combines Future with MaybeSend, providing a convenient bound for async functions that may or may not require Send based on the feature flags.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<F> MaybeSendFuture for F
where F: Future + MaybeSend,