Trait MaybeOwned

pub unsafe trait MaybeOwned { }
A trait for determining whether the buffer is owned or borrowed. Poll-based I/O operations require the buffer to be borrowed, while completion-based I/O operations require the buffer to be owned. This trait provides a way to abstract over the ownership of the buffer. Users could switch between poll-based and completion-based I/O operations at compile-time by enabling or disabling the completion-based feature.

Safety

Do not implement this trait manually.

Implementors

Source

impl<T> MaybeOwned for T